package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````2",```````!``````````*"A````
M`````````$``.``(`$``&0`8``8````%````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````;`````````!L``````````0`````````!````
M!0```````````````````````````````````'R4````````?)0`````````
M``$```````$````&````^)H```````#XF@$``````/B:`0``````B`4`````
M``"P%0```````````0```````@````8````(FP````````B;`0``````")L!
M``````!0`@```````%`"````````"``````````$````!````!P"````````
M'`(````````<`@```````$0`````````1``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0```#XF@```````/B:`0``````^)H!```````(!0``````
M``@%`````````0`````````O;&EB+VQD+6QI;G5X+6%A<F-H-C0N<V\N,0``
M!````!`````!````1TY5```````#````!P`````````$````%`````,```!'
M3E4`^Z"!]*"5UYHG[3R$+Q+UCDY:0441````4`````0````(````(1`0``7`
M!(0H`A`!@(9`@((I``0)(`2)B*`81;H$`@A0````40```%4```!:````6P``
M`&(```!C````9````&8```!G`````````&D```!J````:P```&T`````````
M``````&O-.ANQ=\?ZM/O#L[>1RUK?YI\+L6;MG94/)0@_^0.N(WQ#M5DU'S9
M<5@<XD?&`:Q+X\"ZXY)\6.^7><+E/RSZH6Q@LP&+;VL)0]9GK\QF0D75[(D'
M<-,-%.*>VLWCGC-BV^T-.I<+?ZF<F[[:5QOAIP(*H^#[20``````````````
M`````````````````````````````P`+`,@<````````````````````````
M`P`5``"@`0````````````````#4`@``$@````````````````````````!8
M`P``$@````````````````````````"D`@``$@``````````````````````
M``"K`@``$@````````````````````````!*`P``$@``````````````````
M``````!+`@``$@`````````````````````````1````(```````````````
M``````````#\`@``$@`````````````````````````4`P``$@``````````
M```````````````[`P``(@`````````````````````````-`P``$@``````
M``````````````````#T`@``$@````````````````````````"T````$@``
M```````````````````````&`P``$0````````````````````````"#`0``
M$@`````````````````````````Y`@``$@````````````````````````!8
M`@``$@````````````````````````"$````$@``````````````````````
M```,`0``$@`````````````````````````=`P``$@``````````````````
M``````"=`@``$@````````````````````````"J`0``$@``````````````
M```````````!`0``$0````````````````````````#;`@``$@``````````
M``````````````!G`0``$@````````````````````````#C````$0``````
M```````````````````U`0``$@````````````````````````!0`@``$@``
M``````````````````````!N`P``$@````````````````````````"R`@``
M$@````````````````````````#"````$@````````````````````````"Q
M`0``$@`````````````````````````B`@``$@``````````````````````
M``">`0``$@````````````````````````#P`0``$@``````````````````
M``````"(`@``$@````````````````````````!A`@``$@``````````````
M``````````!J`@``$@`````````````````````````$`@``$@``````````
M``````````````!#`0``$@`````````````````````````M````(```````
M``````````````````"@`P``$0````````````````````````"!`P``(0``
M``````````````````````"0`@``$@````````````````````````!@`P``
M$@````````````````````````"\`0``$0````````````````````````!D
M````$@````````````````````````#&`@``$@``````````````````````
M``!G`P``$@`````````````````````````M!```$@``````````````````
M``````#``@``$@````````````````````````"3````$@``````````````
M``````````"?````$@````````````````````````!<`0``$@``````````
M``````````````#I`@``$@`````````````````````````B`0``$@``````
M```````````````````1`0``$@````````````````````````!6````$@``
M```````````````````````Q`P``$@`````````````````````````6`0``
M$@````````````````````````"3`0``$@````````````````````````#P
M````$@`````````````````````````J`P``$@``````````````````````
M``!U`0``$@````````````````````````!S````$@``````````````````
M```````J`@``$@````````````````````````"6`@``$@``````````````
M``````````"``P``$0````````````````````````""`P``$0``````````
M```````````````*`@``$@````````````````````````#4````$@``````
M``````````````````!3`0``$@````````````````````````"Y`@``$@``
M```````````````````````\````(``````````````````````````1`@``
M$@````````````````````````![`@``$@````````````````````````""
M`@``$@````````````````````````#B`P``$``6`*BP`0``````````````
M```V!```$@`-``!3````````@``````````$!```$@`.`!Q4````````````
M``````!;!```$@`-`"A%````````F`D```````![`P``$@`-```A````````
M2`(````````*!```$@`-`.@]````````!`````````#3`P``$``6`("@`0``
M``````````````#)!```$@`-`/`]````````0`(```````##!```$@`+`,@<
M``````````````````#V!```$@`-`,!.````````0`0```````#'`P``$``6
M`("@`0````````````````!"!```$@`-`#!`````````*`````````!U!```
M$0`/`#!4````````!`````````#U`P``$``6`*BP`0````````````````#M
M`P``$``6`*BP`0````````````````#!!```$@`-`'@\````````.```````
M``#6!```$@`-`"!$````````!`$```````#H!```$@`-`'!#````````B```
M``````!H!```$``5``"@`0````````````````!/!```$@`-`%A`````````
M3`$```````#``P``$``5`("@`0````````````````"J!```$0`5`'B@`0``
M````"`````````#Z`P``$@`-`!A4````````!`````````":!```$@`-`*!3
M````````>`````````!N!```$@`-`$@C``````````````````!J!```(``5
M``"@`0`````````````````;!```$@`-`/A#````````*`````````#A`P``
M$``6`*BP`0````````````````"$!```$@`-``@]````````W`````````"T
M!```$@`-`*A!````````Q`$`````````;&EB<&5R;"YS;RXU+C(V`%])5$U?
M9&5R96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?<W1A<G1?7P!?251-7W)E
M9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI
M=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S
M=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?
M,G!V7V9L86=S`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE
M=UA37V9L86=S`%!,7W1H<E]K97D`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E
M<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP
M=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F
M971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M
M86QL;V,`<&5R;%]A;&QO8P!03%]M96UO<GE?=W)A<`!L:6)D;"YS;RXR`&QI
M8FTN<V\N-@!L:6)P=&AR96%D+G-O+C``<'1H<F5A9%]G971S<&5C:69I8P!C
M;&]S90!O<&5N-C0`7U]E<G)N;U]L;V-A=&EO;@!L<V5E:S8T`')E860`;&EB
M8RYS;RXV`%]?<F5G:7-T97)?871F;W)K`&5X:70`<W1R;F-M<`!?7W-T<F1U
M<`!C;&]S961I<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L
M;&]C`&%B;W)T`&UE;6-H<@!G971P:60`<W1R=&]K`'-T<FQE;@!M96US970`
M<W1R<W1R`')M9&ER`%]?9G!R:6YT9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C
M:&L`7U]L>'-T870V-`!O<&5N9&ER`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED
M`')E861L:6YK`%]?;65M8W!Y7V-H:P!S=')C:'(`<F5A9&1I<C8T`%]?8WAA
M7V9I;F%L:7IE`%]?<W!R:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP
M`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O;@!L9"UL:6YU>"UA87)C:#8T
M+G-O+C$`7U]S=&%C:U]C:&M?9W5A<F0`;&EB8W)Y<'0N<V\N,0!?961A=&$`
M7U]B<W-?<W1A<G0`7U]B<W-?<W1A<G1?7P!?7V)S<U]E;F1?7P!?7V5N9%]?
M`%]E;F0`7U]L:6)C7V-S=5]F:6YI`'!A<E]C=7)R96YT7V5X96,`9V5T7W5S
M97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``<&%R7V)A<V5N86UE
M`'!A<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!?7V1A=&%?<W1A<G0`7TE/7W-T
M9&EN7W5S960`<&%R7V-U<G)E;G1?97AE8U]P<F]C`%]?;&EB8U]C<W5?:6YI
M=`!M>5]P87)?<&P`<&%R7VEN:71?96YV`'AS7VEN:70`<&%R7V9I;F1P<F]G
M`'!A<E]S971U<%]L:6)P871H`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS
M7U!!4E]"3T]4`$=,24)#7S(N,3<```````````(``@`"``(``@`"`````@`"
M``(``@`"`````@````(``@```````@`"``(````"``````````(``@`"````
M```#`````P`"``(``@`#```````$``(``@`"```````"``(``@`"````````
M``(````"`````@`````````"```````#``(``@`"``,```````(````#``(`
M`@`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0```````0`!`(H#```0````(````)>1E@8```0`
M#`4````````!``$`X`$``!`````@````EY&6!@```P`,!0````````$``0`O
M`@``$`````````"7D98&```"``P%````````^)H!```````#!````````%`D
M`````````)L!```````#!`````````@D````````>)\!```````#!```````
M`!A4````````P)\!```````#!`````````B@`0``````T)\!```````#!```
M`````*!3````````X)\!```````#!``````````A````````"*`!```````#
M!`````````B@`0``````&*`!```````#!````````#A8````````(*`!````
M```#!````````-A4````````,*`!```````#!````````,A5````````.*`!
M```````#!````````!A8````````0*`!```````#!````````"!8````````
M2*`!```````#!````````"A8````````4*`!```````#!````````#!8````
M````8*`!```````#!`````````!8````````:*`!```````#!`````````A8
M````````>*`!```````#!````````$!8````````@)\!```````!!```"0``
M````````````B)\!```````!!```#```````````````D)\!```````!!```
M$```````````````F)\!```````!!```$0``````````````H)\!```````!
M!```&0``````````````J)\!```````!!```'```````````````L)\!````
M```!!```*P``````````````N)\!```````!!```+```````````````R)\!
M```````!!```,```````````````V)\!```````!!```.@``````````````
MZ)\!```````!!```0P``````````````\)\!```````!!```1P``````````
M````^)\!```````!!```3```````````````<)T!```````"!````P``````
M````````>)T!```````"!```!```````````````@)T!```````"!```!0``
M````````````B)T!```````"!```!@``````````````D)T!```````"!```
M!P``````````````F)T!```````"!```"```````````````H)T!```````"
M!```"@``````````````J)T!```````"!```"P``````````````L)T!````
M```"!```#```````````````N)T!```````"!```#0``````````````P)T!
M```````"!```#@``````````````R)T!```````"!```#P``````````````
MT)T!```````"!```$@``````````````V)T!```````"!```$P``````````
M````X)T!```````"!```%```````````````Z)T!```````"!```%0``````
M````````\)T!```````"!```%@``````````````^)T!```````"!```%P``
M`````````````)X!```````"!```&```````````````")X!```````"!```
M&@``````````````$)X!```````"!```&P``````````````&)X!```````"
M!```'0``````````````()X!```````"!```'@``````````````*)X!````
M```"!```'P``````````````,)X!```````"!```(```````````````.)X!
M```````"!```(0``````````````0)X!```````"!```(@``````````````
M2)X!```````"!```(P``````````````4)X!```````"!```)```````````
M````6)X!```````"!```)0``````````````8)X!```````"!```)@``````
M````````:)X!```````"!```)P``````````````<)X!```````"!```*```
M````````````>)X!```````"!```*0``````````````@)X!```````"!```
M*@``````````````B)X!```````"!```*P``````````````D)X!```````"
M!```+@``````````````F)X!```````"!```+P``````````````H)X!````
M```"!```,0``````````````J)X!```````"!```,@``````````````L)X!
M```````"!```,P``````````````N)X!```````"!```-```````````````
MP)X!```````"!```-0``````````````R)X!```````"!```-@``````````
M````T)X!```````"!```-P``````````````V)X!```````"!```.```````
M````````X)X!```````"!```.0``````````````Z)X!```````"!```.P``
M````````````\)X!```````"!```/```````````````^)X!```````"!```
M/0```````````````)\!```````"!```/@``````````````")\!```````"
M!```/P``````````````$)\!```````"!```0```````````````&)\!````
M```"!```00``````````````()\!```````"!```0@``````````````*)\!
M```````"!```1```````````````,)\!```````"!```10``````````````
M.)\!```````"!```2```````````````0)\!```````"!```20``````````
M````2)\!```````"!```2@``````````````4)\!```````"!```2P``````
M````````6)\!```````"!```30``````````````8)\!```````"!```3@``
M````````````:)\!```````"!```3P``````````````_7N_J?T#`)&L`0"4
M_7O!J,`#7]8`````\'N_J=```)`1MD;Y$*(UD2`"']8?(`/5'R`#U1\@`]70
M``"0$;I&^1#"-9$@`A_6T```D!&^1OD0XC61(`(?UM```)`1PD;Y$`(VD2`"
M'];0``"0$<9&^1`B-I$@`A_6T```D!'*1OD00C:1(`(?UM```)`1SD;Y$&(V
MD2`"'];0``"0$=)&^1""-I$@`A_6T```D!'61OD0HC:1(`(?UM```)`1VD;Y
M$,(VD2`"'];0``"0$=Y&^1#B-I$@`A_6T```D!'B1OD0`C>1(`(?UM```)`1
MYD;Y$"(WD2`"'];0``"0$>I&^1!"-Y$@`A_6T```D!'N1OD08C>1(`(?UM``
M`)`1\D;Y$((WD2`"'];0``"0$?9&^1"B-Y$@`A_6T```D!'Z1OD0PC>1(`(?
MUM```)`1_D;Y$.(WD2`"'];0``"0$0)'^1`".)$@`A_6T```D!$&1_D0(CB1
M(`(?UM```)`1"D?Y$$(XD2`"'];0``"0$0Y'^1!B.)$@`A_6T```D!$21_D0
M@CB1(`(?UM```)`1%D?Y$*(XD2`"'];0``"0$1I'^1#".)$@`A_6T```D!$>
M1_D0XCB1(`(?UM```)`1(D?Y$`(YD2`"'];0``"0$29'^1`B.9$@`A_6T```
MD!$J1_D00CF1(`(?UM```)`1+D?Y$&(YD2`"'];0``"0$3)'^1"".9$@`A_6
MT```D!$V1_D0HCF1(`(?UM```)`1.D?Y$,(YD2`"'];0``"0$3Y'^1#B.9$@
M`A_6T```D!%"1_D0`CJ1(`(?UM```)`11D?Y$"(ZD2`"'];0``"0$4I'^1!"
M.I$@`A_6T```D!%.1_D08CJ1(`(?UM```)`14D?Y$((ZD2`"'];0``"0$59'
M^1"B.I$@`A_6T```D!%:1_D0PCJ1(`(?UM```)`17D?Y$.(ZD2`"'];0``"0
M$6)'^1`".Y$@`A_6T```D!%F1_D0(CN1(`(?UM```)`1:D?Y$$([D2`"'];0
M``"0$6Y'^1!B.Y$@`A_6T```D!%R1_D0@CN1(`(?UM```)`1=D?Y$*([D2`"
M']:P``#P$7I'^1#".Y$@`A_6L```\!%^1_D0XCN1(`(?UK```/`1@D?Y$`(\
MD2`"']:P``#P$89'^1`B/)$@`A_6L```\!&*1_D00CR1(`(?UK```/`1CD?Y
M$&(\D2`"']:P``#P$9)'^1""/)$@`A_6L```\!&61_D0HCR1(`(?UK```/`1
MFD?Y$,(\D2`"']:P``#P$9Y'^1#B/)$@`A_6L```\!&B1_D0`CV1(`(?UK``
M`/`1ID?Y$"(]D2`"']:P``#P$:I'^1!"/9$@`A_6L```\!&N1_D08CV1(`(?
MUK```/`1LD?Y$((]D2`"']:P``#P$;9'^1"B/9$@`A_6_7NYJ?T#`)'S4P&I
MLP``\+0``/!CWD?YHH<$J:(C`9%D`$#YI#<`^00`@-*@7P"YH4,!D:!S`9&*
M__^7H```\*(``/``]$?Y0NQ'^>$#`JJ,#`"4H```\`#41_D``$`Y8`$`-4__
M_Y?"``"00%``^4`.`+2T``#P&O__EX#21_D``$"Y4___EQ^$)#F4TD?Y@`)`
MN4___Y<!Z%,Y(0`?,@'H$SF``D"Y2O__EP+H4SFA7T"Y`P#\DD(``#("Z!,Y
M(10`$;5;`JFW&P#Y(7Q`DS\``^MH"@!4(/!]TSG__Y>E*T#YP@``D-0``)"$
M(@*11SQ`^0,``/`!``#P8\`?D:@`0/DAX!^1A@"`4J)?0+D(#`"I!P0!J5\$
M`'&&!`"Y@`0`^4T!`%0A`(#2Y@"`DB00`!&C>&'XQ,PDBR$$`)%?``%K`V@D
M^$S__U26(@*111``$07,)8OC`P"J`0``L`0`@-+`#D#Y0@P`$;^`'_@AP#*1
M;___E_4#`"J@`P`TEB("D;>3`9'`#D#Y[?[_EP```/#A`Q>J`&`5D:<$`)0`
M`@"TE"("D8`.0/G1_O^75/__EW/>1_G@`Q4JHC=`^6$"0/E!``'*80,`M;5;
M0JGS4T&IMQM`^?U[QZC``U_6P`I`^>```+0&#`"4[O__%\`.0/EO__^7]0,`
M*N'__Q<```#PX0,7J@"`$Y&+!`"4P`H`^8#\_[3Z"P"4XO__%Z$``/````#P
M`*`?D2'D1_DD__^7\_[_E[5;`JD@`(!2MQL`^8/^_Y<=`(#2'@"`TN4#`*KA
M`T#YXB,`D>8#`)&@``#P`/!'^:,``/!CZ$?YI```\(2\1_F^_O^7\?[_EZ``
M`/``V$?Y0```M.G^_Q?``U_6`````,```)````*1P0``D"$``I$_``#KH```
M5*$``/`AP$?Y00``M"``'];``U_6'R`#U<```)````*1P0``D"$``I$A``#+
M(?Q#DR'\08LA_$&3P0``M*(``/!"_$?Y8@``M$``']8?(`/5P`-?UA\@`]7]
M>[ZI_0,`D?,+`/G3``"08`)".4`!`#6@``#P`,1'^8```+3```"0``1`^5/^
M_Y?8__^7(`"`4F`"`CGS"T#Y_7O"J,`#7];>__\7`````/^#"M&H``#P!.``
MD0G@`9']>P"I_0,`D:)C`)$!W4?Y1R``D2,`0/FC3P'Y`P"`TH$`0+F#A$#X
M(0C`6N&`'_B?``GK8?Q@TV7\:-,FW'C3I1QXDB$<"%/&''"2(0`&JJ/@0ZHA
M``.JX00!^"'^_U1&``B11`!`^4(@`)%#!$#Y11Q`^4$P0/EC``3*7P`&ZR$`
M!<HA``/*(_Q?TV$$`:HA?$"203P`^6'^_U0%$$"I@`!GG@8<0:GA`&>>P@!G
MGH'\0M,A>`2JH_Q;TT`<82XL?$"2@0%GGF,4!:JKOT&I*C./TDI0J_()$$#Y
M#0!FGJ``9YYK`0J+HOQ"TR`<8BY">`6J[P$*BR$``LJC02.+L!=`^6,`"XM-
M?$"28P`)"Q`""HL.`&:>:_Q;TVL5`ZHA``.*(0`,RK%C0/DA``:+S@$'BR$`
M$(O.`0^+;_Q"TVL!#@OC>0.J;OU;TT(``\I"``N*SA4+JLX!`0M!``W*KPM#
MJ7#]0M,0>@NJ(0`,B^\!"HML`!#*(0`/BV-\0)++_5O3C`$.BL_]0M-K%0ZJ
M[WD.JHP!`\IK`0$+3@`*BXP!#8L-`@_*`7Y`DHP!#HMB_5O3K0$+BF[]0M-"
M%`NJK0$!RLMY"ZI"``P+K0$#B^P!"\KC?4"2L#]$J4[\6]/.%0*JC`$"BA`"
M"HN,`0/*K0$0B^\!"HO.`0T+@0$!BU#\0M/-_5O3`GH"JB$`#XNM%0ZJS_U"
MTZT!`0ML`0+*X7D.JFM]0)*P/T6IC`$.BHP!"\JN_5O3$`(*BX,!`XM,``'*
M8P`0BT)\0)+.%0VJC`$-BLX!`PN,`0+*L/U"TP-Z#:KO`0J+BP$+B\W]6]-K
M`0^+K14.JL_]0M.M`0L++``#RNMY#JJP/T:I(7Q`DHP!#HJN_5O3C`$!RA`"
M"HN"`0*+;``+RD(`$(MC?$"2SA4-JHP!#8K.`0(+C`$#RK#]0M/O`0J+@0$!
MB\S]6],">@VJ(0`/BXP5#JK/_4+3C`$!"VT!`LKA>0ZJ:WU`DK`_1ZFM`0Z*
MK0$+RH[]6],0`@J+HP$#BTT``<IC`!"+0GQ`DLX5#*JM`0R*D/U"T\X!`PL,
M>@RJK0$"RN\!"HLC``S*JP$+B\W]6],A?$"2:P$/B[!#0/FM%0ZJ8P`.BL_]
M0M.M`0L+[WD.JF,``<H.`@J+BP$/RF,``HNB_5O3C'U`DF,`#HNP1T#Y0A0-
MJFL!#8JN_4+30@`#"\YY#:IK`0S*#0(*B^,!#LIK`0&+0?Q;T^]]0))K`0V+
ML$M`^2$4`JIC``**3?Q"TR$`"PNM>0*J8P`/RLL!#<IC``R+(OQ;TPP""HO.
M?4"28P`,BT(4`:IK`0&*L$]`^4(``PMK`0[*+/Q"TXQY`:H0`@J+:P$/BT'\
M6]-K`1"+(10"JE#\0M,A``L+HP$,R@MZ`JIC``**@@$+RJ]30/FM?4"2C'U`
MDD(``8IC``W*0@`,RF,`#HM"``V+[@$*BR_\6].PMTJI8P`.B^\5`:HN_$+3
M[P$#"\YY`:KC_5O3`0(*BV,4#ZI"``&+80$.RD)`(XMK?4"2(0`/BD-\0)(A
M``O*J@$*BR$`#(OM_4+3;/Q;TR$`"HN,%0.JJGD/JBQ`+(NM7T#YP0$*RI!]
M0)(A``)*(G2=TBL`"XLBVZWR;_Q"TZ$!`HL-_EO3XWD#JF$!`8NM%1"J2P$#
MRBU`+8MK`0Q*KWU`DFM!+HOL_5O3+@("BP'^0M-K`0Z+(7@0JHP5#ZIL02R+
ML&=`^6L``<J.?4"2;0$-2A`"`HNJ02J+Z_U"T\W]6]-K>0^J2@$0BZT5#JI-
M02V+L&M`^2H`"\JO?4"22@$,2A`"`HM*02.+[/U;T\/]0M-*`1"+8W@.JHP5
M#ZI,02R+L&]`^6H!`\J.?4"22@$-2A`"`HM!02&+S?U;T^K]0M,A`!"+2GD/
MJJT5#JHM0"V+L'-`^6$`"LJO?4"2+``,2A`"`HN+02N+P?U"T^S]6],A>`ZJ
M:P$0BXP5#ZIL02R+L'=`^4L!`<J.?4"2;0$-2A`"`HNC02.+Z_U"T\W]6]-K
M>0^J8P`0BZT5#JJP>T#Y;4`MBR,`"\JO?4"2;``,2A`"`HN*02J+P_U"T^S]
M6]-C>`ZJ2@$0BXP5#ZI,02R+L']`^6H!`\J.?4"230$-2A`"`HNA02&+ZOU"
MT\W]6]-*>0^J(0`0BZT5#JHM0"V+L(-`^6$`"LJO?4"2+``,2A`"`HN+02N+
MP?U"T^S]6],A>`ZJ:P$0BXP5#ZIL02R+L(=`^4L!`<J.?4"2;0$-2A`"`HNC
M02.+Z_U"T\W]6]-K>0^J8P`0BZT5#JIM0"V+L(M`^2,`"\JO?4"2;``,2A`"
M`HN*02J+P_U"T^S]6]-C>`ZJ2@$0BXP5#ZI,02R+L(]`^6H!`\J.?4"230$-
M2A`"`HNA02&+ZOU"T\W]6]-*>0^J(0`0BZT5#JHM0"V+80`*RBP`#$K!_4+3
M(7@.JJ]]0)*P.U*IBT$KB^S]6],0`@*+C!4/JFL!$(MK02R+3`$!RG!]0)*-
M`0U*HT$CB^S]0M/-`0*+#OY;TXQY#ZIC``V+SA40JFY`+HLC``S*:P`+2@/^
M0M-C>!"JSWU`DJU#4ZEJ02J+JP$"B^W]6]-*`0N+K14/JDU!+8N*`0/*3@$.
M2NK]0M-*>0^J$`("B\%!(8NK?4"2(0`0BW``"LH-`@U*;OU;TW#]0M/.%0NJ
M"WH+JBY`+HNO0U2IP7U`DJQ!+(LM_%O3[P$"BZT5`:J,`0^+3P$+RHQ!+8ON
M`0Y*C7U`DA`"`HO#02.+KOU;T\X5#:JQ_4+3+_Q"TV,`$(O#`0,+X7D!JBYZ
M#:IP`0'*KT=5J1`"#$K-?4"2+'Q`D@I"*HLA``ZJX@$"BV_\6],A``.*</Q"
MTT(!`HOJ%0.JCP$-BD(!`@L#>@.J(0`/JHJ;E])O?$"2:N.Q\BM`*XLQ`@J+
MP0$#JFL!$8LA``**L0$/BE#\6],A`!&J$!8"JJY'5JE2_$+3"P(+"T)Z`JI0
M?$"2S@$*BR$`#(MC``*J;/U;TW+]0M,A``Z+C!4+JNX!$(IC``N*C`$!"V,`
M#JI!>@NJ8P`-BRY\0)(M`@J+B_U;TT(``:IC``V+DOU"TPT"#HJQNT#Y:Q4,
MJD(`#(IK`0,+0@`-JD-Z#*I"``^+;7Q`DB\""HML_5O3(0`#JG+]0M-"``^+
ML;]`^<\!#8J,%0NJ(0`+BHP!`@LA``^J0GH+JB$`$(M/?$"2,`(*BXO]6]-C
M``*JDOU"TR$`$(NQPT#YL`$/BFL5#*IC``R*:P$!"V,`$*I!>@RJ8P`.BS!\
M0)(N`@J+;/U;TT(``:IR_4+38P`.B[''0/GN`1"*C!4+JD(`"XJ,`0,+0@`.
MJD-Z"ZI"``V+;GQ`DBT""HN+_5O3(0`#JI+]0M-"``V+L<M`^0T"#HIK%0RJ
M(0`,BFL!`@LA``VJ0GH,JB$`#XM-?$"2+P(*BVS]6]-C``*J<OU"TR$`#XNQ
MST#YSP$-BHP5"ZIC``N*C`$!"V,`#ZI!>@NJ8P`0BR]\0)(P`@J+B_U;TT(`
M`:J2_4+38P`0B['30/FP`0^*:Q4,JD(`#(IK`0,+0@`0JD-Z#*I"``Z+<'Q`
MDBX""HML_5O3(0`#JG+]0M-"``Z+L==`^>X!$(J,%0NJ(0`+BHP!`@LA``ZJ
M0GH+JB$`#8M.?$"2+0(*BXO]6]-C``*JDOU"TR$`#8NQVT#Y#0(.BFL5#*IC
M``R*:P$!"V,`#:I!>@RJ8P`/BRU\0)(O`@J+;/U;TT(``:IR_4+38P`/B['?
M0/G/`0V*C!4+JD(`"XJ,`0,+0@`/JD-Z"ZI"`!"+;WQ`DC`""HN+_5O3(0`#
MJI+]0M-"`!"+L>-`^;`!#XIK%0RJ(0`,BFL!`@LA`!"J0GH,JB$`#HM0?$"2
M+@(*BVS]6]-C``*J<OU"TR$`#HNQYT#Y[@$0BHP5"ZIC``N*C`$!"V,`#JI!
M>@NJ8P`-BRY\0)(M`@J+B_U;TT(``:J2_4+38P`-B['K0/D-`@Z*:Q4,JD(`
M#(IK`0,+0@`-JD-Z#*I"``^+;7Q`DB\""HML_5O3(0`#JD(`#XNQ[T#YSP$-
MBHP5"ZHA``N*C`$""W+]0M,A``^J0GH+JB$`$(N+_5O3,`(*BR$`$(MK%0RJ
M:P$!"T]\0)*Q!UZI8P`"JK`!#XIC``R*DOU"TV,`$*I,>@RJ,0(*BY!]0))"
M``RJ8P`.BV[]6]/.%0NJ0@`+BF,`$8OQ`1"*PP$#"T(`$:IN_4+3(0`*B\MY
M"ZI"``V+;?Q;TVY]0))"``&+K14#JH$!"ZI20"V+K/M`^0("#HHA``.*37Y`
MDB$``JIB_$+30W@#JHH!"HLA``^+K/U;TV(!`\HA``J+C!4-JJ_]0M,L0"R+
M00`22B$`$(N1?4"2JL-?J<(ZF-)"3+GR*_Y;TTH!`HMK%1&J(0`*B^IY#:HK
M0"N+80`*RF]]0)(A``Q*[?U;TPP"`HLA``Z++OY"T\YY$:HA``R+K14/JDP!
M#LHM0"V+H0=!^;!]0)*+`0M*(0`"BPS^6]-K02.+X_U"TVL!`8N,%1"J87@/
MJFQ!+(NC"T'YRP$!RH]]0))K`0U*8P`"B^W]6]-J02J+"_Y"TVMY$*I*`0.+
MK14/JB,`"\I-02V+J@]!^;!]0))C``Q*2@$"BPS^6]-C0"Z+[OU"TV,`"HN,
M%1"JRGD/JFQ`+(MN`0K*HQ-!^8]]0)+.`0U*8P`"B^W]6]/!02&+#OY"TR$`
M`XNM%0^JPWD0JBU`+8M0`0/*H1=!^:Y]0)(0`@Q*(0`"B\S]6],+0BN+\/U"
MTVL!`8N,%0ZJ`7H/JFQ!+(MP``'*JQM!^8]]0)(0`@U*:P$"B^W]6],*0BJ+
MT/U"TTH!"XNM%0^J"WH.JDU!+8LP``O*JA]!^:Y]0)(0`@Q*2@$"B\S]6],#
M0B.+\/U"TV,`"HN,%0ZJ"GH/JFQ`+(MP`0K*HR-!^8]]0)(0`@U*8P`"B^W]
M6],!0B&+T/U"TR$``XNM%0^J`WH.JBU`+8M0`0/*H2=!^:Y]0)(0`@Q*(0`"
MB\S]6],+0BN+\/U"TVL!`8N,%0ZJ`7H/JFQ!+(MP``'*JRM!^8]]0)(0`@U*
M:P$"B^W]6],*0BJ+T/U"TTH!"XNM%0^J"WH.JDU!+8LP``O*JB]!^:Y]0)(0
M`@Q*2@$"B\S]6],#0B.+\/U"TV,`"HN,%0ZJ"GH/JFQ`+(MP`0K*HS-!^8]]
M0)(0`@U*8P`"B^W]6],!0B&+T/U"TR$``XNM%0^J`WH.JBU`+8M0`0/*H3=!
M^:Y]0)(0`@Q*(0`"B\S]6],+0BN+\/U"TVL!`8N,%0ZJ`7H/JFQ!+(MP``'*
MJSM!^8]]0)(0`@U*:P$"B^W]6],*0BJ+T/U"TTH!"XNM%0^J"WH.JDU!+8LP
M``O*JC]!^:Y]0)(0`@Q*2@$"B\S]6],#0B.+\/U"TV,`"HN,%0ZJ"GH/JFQ`
M+(NO0T'Y8P$*RI!]0))M``U*H4$ABP/^6]/M`0*+S_U"TV,4$*HA``V+[7D.
MJB%`(XNO1T'Y0P$-RBY\0))C``Q*#/Y"T^\!`HN,>1"J:T`KB\/]6]-K`0^+
M8Q0.JK`!#,JO2T'Y8P`+"P$"`4K+_4+3*D`JB^$!`HMB_%O32@$!BT(4`ZIA
M>0ZJ0@`*"R8`!@L(W4?YAP$'"ZD!"0M%``4+@P`#"P8<`:D%#`"I"1``^:%/
M0?D``4#Y(```RH```+7]>T"I_X,*D<`#7]9T^O^7'R`#U?U[O*G]`P"1\PL`
M^8`'`+2B``#0N!\`^4+X1_E8`$#Y.`<`M+43`/D5`(!2`@!`.5_T`'%$&$!Z
M00,`5!,#0/F3!0"TMM\"J;5^0).T#P#Y]P,!JO8#`*KT`QBJX`,3JN(#%:KA
M`Q:J,/K_EX```#5@:G4X'_0`<4`"`%23CD#X\_[_M;370:FVWT*IN!]`^>`#
M$ZKS"T#Y_7O$J,`#7];U`P"JHAY`.%_T`'%$&$!ZH?__5+4"`$OA__\7'R`#
MU90"&,NU!@"1E/Y#D_0"`+ES`A6+X`,3JK@?0/FTUT&IMM]"J?,+0/G]>\2H
MP`-?UK430/FX'T#YYO__%Q,`@-+D__\7$P"`TK@?0/GA__\7_7N\J?T#`)'U
M6P*IM@``T/-3`:FS``#0]0,`JL#>1_ES^D?YM-,`D0$`0/FA'P#Y`0"`TN$#
M%*K@`Q6JK?__E^`!`+2C-X"Y8@)`^4`,`XL!!$#Y07@C^.'^_[0`(`"1`01`
M^0$``/FA__^UX0,4JN`#%:J?__^78/[_M=;>1_FA'T#YP`)`^2```,J@``"U
M\U-!J?5;0JG]>\2HP`-?U@;Z_Y<?(`/5_7NYJ?T#`)'S4P&I\P,!JO5;`JFU
M``#0]V,#J?0#`*JAWD?Y8`)`.2(`0/FB-P#Y`@"`TA_T`'%S%I.:X`,3JH#Y
M_Y?V`P"JH9,!D>`#%*I^__^7X`<`M/<#`*IY^?^7'P`6ZZ(&`%2X9X"YMP``
MT!CS?=.``D`Y'_0`<0080'J`#`!4X0,4JB`<0#@?]`!Q!!A`>J'__U0A`!3+
M(7Q`D_?Z1_G`"@"1```!B_8"0/F@^?^7P&HX^*`+`+2C9X"Y@`8`D>("0/F!
M`D`Y/_0`<4)X8_@D&$!Z00``.<```%0!%$`X01P`.#_T`'$D&$!Z@?__5$$$
M`)&@!X!20```.6`60#@@%``XP/__-0``@%*UWD?YHC=`^:$"0/E!``'*H0@`
MM?-30:GU6T*I]V-#J?U[QZC``U_6``"`TF%J8#CA:B`X``0`D:'__S7P__\7
MMP``T+EK!*F[*P#YX/I'^1@`0/D``T#Y@`4`M.$#&*H``(!2`@``%.`#&2HB
MC$#X&00`$:+__[4`#``1`'Q]DZ$``/`BB$"Y@@(`-2(`@%(BB`"Y8_G_E_L#
M`*K``P"T.G]`D^$#&*I8\WW3X@,8JACY_Y?@^D?Y&P``^5H'`)%_>SKXN6<`
MN;LK0/FY:T2II?__%Q\@`]7A`P"JX`,8JH#Y_Y?[`P"JX/I'^1L``/D[`0"T
M.G]`DUCS?=/P__\7`0"`TJ/__Q<``H#2&0"`4MS__Q>Y:T2INRM`^0``@!*X
M__\7N6L$J;LK`/EU^?^7_7NRJ?T#`)'S"P#YLP``T&'>1_DB`$#YHF\`^0(`
M@-+```"TM`\`^?0#`*H!`$`Y00$`-;0/0/ESWD?YH6]`^6`"0/D@``#*X`D`
MM?,+0/G]>\ZHP`-?UK87`/D%^?^7]@,`JB`'`+2W8P.I&```T+DC`/D8PQ&1
MN6,!D=<%@%+@`Q:JE_G_EX`&`+0!3$`YX0(!:^$``%0!4$`Y(?__-.$"`6MA
M``!4`51`.>$#`4N!_O\TM1,`^15,`)&Z)P#YX`,4JL_X_Y?Z`P"JX`,5JLSX
M_Y<``!H+``@`$0!\0),$^?^7Y0,5JN0#%*KC`QBJ^@,`J@(`@)(A`(!2Q?C_
ME^(#&:KA`QJJ``"`4LGX_Y<?!``QH```5*!K0+D`#!02'Q!`<:`"`%3@`QJJ
MH?G_E^`#&JIC^?^7M1-`^;HG0/G0__\7'R`#U;0/0/FV%T#YNO__%Q\@`]7@
M`Q:J&?G_E^`#%*I#^?^7MM]"J;CG0ZFT#T#YL?__%^`#&JJA__^7[/__%[37
M`:FVWP*IN.<#J;HG`/D/^?^7_7N^J?T#`)'S4P&ILP``T/0#`*ISTD?Y8`)`
MN?OX_Y<"``B1X0,4J@``@%([^?^7P```-```@%+S4T&I_7O"J,`#7]8?(`/5
M8`)`N>_X_Y<`$$*Y``P4$A\00''@``!48`)`N>GX_Y<`$$*Y``P4$A\H0'$!
M_O]400"`4N`#%*H"^?^7'P``<>`7GQKS4T&I_7O"J,`#7]80"H+2_V,PR^+_
M@=+]>P"I_0,`D?,+`/FS``#0]5L"J;4C`9'W8P.I]@,`JF/>1_GW`P&J````
MT.$#%:ID`$#YI"<(^00`@-(`X!&1<?C_EQ\``'%M!0!4`@0`4;0/`/FA``#0
MH\IB."'01_DX`$"Y@P,`-.(#`"I4?$"3X06`4N(#%*K@`Q6J)OG_E\`"`+3@
M`Q@JM_C_E^,#%*KB`Q6JX0,6JB?Y_Y>T#T#Y<]Y'^:$G2/E@`D#Y(```RJ`"
M`+7U6T*I$`J"TO=C0ZG]>T"I\PM`^?]C,(O``U_6'R`#U<+\_S6T#T#YX`,8
M*J'X_Y?B`Q>JX0,6JG[X_Y?L__\7H```T`#01_D8`$"Y]___%[0/`/FC^/^7
M_7N_J:```-#]`P"1`-!'^0``0+F1^/^7H@``T`,``-#]>\&H`0``T$+,1_EC
MX!"1(2`2D<GX_Q?]>[ZI_0,`D?,+`/FS``#0<])'^6`"0+F"^/^7Z___EV`"
M0+E_^/^7\PM`^?U[PJ@$``#0A(`?D0(``+`!``#0!0"`4N,#!*I"`#N1(:`2
MD=#X_Q<?(`/5$`J$TO]C,,L`"(+2_7L`J?T#`)'S4P&IM```T/5;`JFV`P"+
M@-Y'^;/C`)$!`$#YH2<0^0$`@-(T^/^7Y`,`*@4``-`#``#0I0`3D6,@$Y$B
M`(+2(0"`4N`#$ZKW]_^7`@""TN$#%JK@`Q.J__?_EP`#^#?S`P"J``0`$0!\
M0),F^/^7]0,`JL```+1S?D"3X0,6JN(#$ZK8]_^7OVHS.)3>1_G@`Q6JHB=0
M^8$"0/E!``'*(0$`M?-30:D0"H32]5M"J?U[0*G_8S"+P`-?UA4`@-+S__\7
M2/C_EQ\@`]7(__\7'R`#U1`.@M+_8S#+_7L`J?T#`)'U6P*IM@``T/-3`:GU
M`P&JPMY'^?,#`*JADP&1````T$,`0/FC-PCY`P"`T@"`$Y'"_?^7]`,`JN$%
M@%+@`Q.JA/C_ER`"`+0```#0X0,3J@#`$Y$G_O^7X`,3JM;>1_FB-TCYP0)`
M^4$``<JA#0"U\U-!J1`.@M+U6T*I_7M`J?]C,(O``U_6MQL`^>`#$ZJY(P#Y
M%P``T+LK`/FE]_^7X0(4D?D#`"K@`Q6JG??_E_L#`*K@"@"TN!\`^;6C`9&Z
M)P#Y&```T!H``-`8(Q216F,3D6`#0#D`!P`TM```M.$#&ZK@`Q2J)OC_ER`%
M`#3@`QNJC_?_EV'#((LA\%\X/[P`<>$``%0`!`!18<,@BW_+(#@A\%\X/[P`
M<6#__U0A!P`1(```"Q_\/W',`P!4Y`,;JKL``-`"`(+2(0"`4N8#$ZKE`QBJ
M`P``T.`#%:IC0!21>_?_EWO31_E@`T"YW/?_EP(`")'A`Q6J``"`4GSW_Y?@
M```U8`-`N=7W_Y<`$$*Y``P4$A\@0'%@`@!4X0(4D0``@-)B]_^7^P,`JJ#Y
M_[6W8T.IN6M$J;LK0/FF__\7'R`#U;0``+3A`QJJX`,4JN_W_Y=`_O\T^P,:
MJB``@%+3__\7(0"`4N`#%:K<]_^78/W_->$#%:H```#0`,`3D;_]_Y?@`Q6J
M=??_E[LK0/FW8T.IN6M$J93__Q>W&T#YN2-`^;LK0/F+__\7MV,#J;EK!*F[
M*P#YM??_EP$`0#GB`P"JP0``-``$`)$_O`!Q0A"`F@$`0#F!__\UX`,"JL`#
M7];]>[ZI_0,`D:`#`+2S4P&I\P,`JA0`0#D4`P`T+_?_EP`$`-%B`@"+?P("
MZV($`%1@:F`X'[P`<:```%0<```40`!`.1^\`'$A`P!40@0`T7\"`NMA__]4
MG[X`<6`&`%2S4T&I````L/U[PJ@`(!210O?_%Q\@`]6S4T&I0`"`TE+W_Y?`
M!`"T`@``L$)@$Y%"`$!Y`@``>?U[PJC``U_60`!`.1^\`'%@`0!40@0`T7\"
M`NMC__]4?P("Z\$``%3F__\7'R`#U4``0#D?O`!Q@0``5$($`-%_`@+K8___
M5$(`$\M`"`"1'P1`\6@!`%2@``#0!*`"D>$#$ZH#`(+20@0`D>`#!*HT]_^7
MLU-!J?U[PJC``U_6LU-!J0``@-+]>\*HP`-?UD``@-(G]_^70/__M`(``+!"
M8!.10@!`>0(``'FS4T&IU/__%Q\@`]7]>[BI`0``L"'@$)$```"P_0,`D?-3
M`:FS``"P]5L"J0!@%)%CWD?Y%@``L/=C`ZD7``"P)AQ!J6(`0/FB/P#Y`@"`
MTB040JFF'P6I(6!`>1@``+"AXP!Y%```L*07!JF4XA61M3,!D0[]_Y<```"P
M`*`4D0O]_Y<```"P`,`4D0C]_Y<```"P```5D07]_Y?`(A61`_W_EP```+``
M8!61`/W_E^""$Y'^_/^7`*,5D?S\_Y?@`Q2J^OS_EP```+``(!:1]_S_EP``
M`+``P!.1]/S_EP```+#A`Q6J`&`6D:S\_Y>```"TX0,`JN`#%*H6_?^7````
ML.$#%:H`P!:1I/S_EZ```+0"``"PX0,`JD`@%Y$-_?^7````L.$#%:H`8!>1
MF_S_ET`"`+3A`P"JX((3D07]_Y<!``"PP"(5D2%`&)$!_?^7<]Y'^:$_0/E@
M`D#Y(```RD`#`+7S4T&I]5M"J?=C0ZG]>\BHP`-?U@```+#A`Q6J`*`7D87\
M_Y>``0"U`0``L+1#`9%"`8#2(0`8D:"'`9'(]O^7X/S_-8%N`)$`HQ61Z/S_
ME^/__Q?A`P"J`*,5D>3\_Y??__\7YO;_EQ\@`]7]>[VI_0,`D?-3`:FS``"P
MM```T&'>1_F`$D"Y(@!`^:(7`/D"`(#2'P0`,2`!`%1SWD?YHA=`^6$"0/E!
M``'*(0(`M?-30:G]>\.HP`-?UJ&3`)$```"P`*`5D5O\_Y?A`P"J``"`4J$`
M`+0@`$`Y'\``<0080'K@!Y\:@!(`N>S__Q?#]O^7_7N_J?T#`)%D]O^7X_;_
MEX```+0``$#Y_7O!J,`#7]8``(#2_?__%_U[NZG]`P"1\PL`^;,``+#U6P*I
M%0``L/<;`/FW8AB18MY'^?8#`*JA$P&1X`,7JD,`0/FC)P#Y`P"`TC?\_Y=@
M`0"TM`\`^?0#`*H!`$`YP0``-.$#%JH2]_^7(`(`M+0/0/D%```4M`]`^>$#
M%JJ@8AB1E_S_EW/>1_FA)T#Y8`)`^2```,J@`P"U]5M"J?,+0/GW&T#Y_7O%
MJ,`#7];@`Q:J&_;_E_4#`*K@`Q2J&/;_EZ`"`(L`"`"14?;_E^8#%*KD`Q:J
M!0``L`,``+"E`!218T`4D0(`@)+U`P"J(0"`4@_V_Y?A`Q6JX`,7JGC\_Y>T
M#T#YX/__%[0/`/EX]O^7'R`#U1`ZD-+_8S#+J@``T$I!`)$+!)#2_7L!J?U#
M`)&M`PN+1)5`J?5;`ZFV``"P]R,`^?HO`/GW`P"J\Q,`^;4S`I',WD?Y&@``
ML$`%0ZF.`4#YKLT`^0X`@-)"#4*IH`<-J48=1*FD%PFI2"5%J:(/#*E+#4#Y
MX0,5JDHQ0/E`@Q.1IA\.J:BG"JFK4P#YJE\`^>#[_Y>```"T`0!`.?,#`*H!
M$P`UM`\`^;CG`ZF[*P#YB/__E_0#`*H`$P"TX`,4JM+U_Y<`^'_3``0`D0OV
M_Y>$`D`Y^0,`JH0!`#0```"P\P,9JAC`&)'@`Q.JXP,8J@(`@)(A`(!2R/7_
MEW,*`)&$'D`X)/__-:!C0/E@"P"TN`,#D3,`@-(&```4'R`#U7,&`)$`#Q.+
M`(!?^&`*`+3A`Q6JM_O_E_0#`*H@__^T`0!`.>'^_S06_?^7H/[_-.`#%*K5
M]?^7^P,`JN`(`+3@`QNJJ?7_E_,#`*K@`QFJIO7_EQ,`$PMS$A`1&```L'-^
M0)/@`Q.JW/7_E^<#&:H%(Q21Y`,;J@8``+`#``"PQN`8D6,`&9$"`("2]`,`
MJB$`@%*9]?^7`3B`4N`#%*J"]O^7'P0`,:$``%1W]O^7!0!`N;]$`''!#`!4
MNP``L'O31_E@`T"Y\/7_EP(`")'A`Q2J``"`4C#V_Y?Y`P`J``8`-*```+#C
M`D#YY`,4J@(``+``R$?Y0F`:D2$`@%(3`(#2``!`^0CV_Y>T#T#YN.=#J;LK
M0/G6WD?Y`020TJ$#`8O@`Q.J(LQ`^<$"0/E!``'*H3D`M?5;0ZD0.I#2_7M!
MJ?,30/GW(T#Y^B]`^?]C,(O``U_6N$,"D10`@%(3VW3XLP$`M&`"0#E@`0`T
MX`,3JI0&`!'"_/^7(/__-.`#$ZJ!]?^7^P,`JJ#U_[43VW3XL_[_M1L`@-*I
M__\78`-`N;GU_Y<`$$*Y``P4$A\00'&!^?]4O"\`^6`#0+FR]?^7'!A"N6#U
M_Y>?`P!KP`4`5+PO0/G#__\7'R`#U?[^_Y?@`Q.J:/7_E_,#`*K*__\7'R`#
MU;BC`I$3`(!2`-MS^(`!`+3A`Q6J<P8`$3C[_Y=@__^T`0!`.2'__S1:]?^7
M]`,`JJ#K_[4`VW/XP/[_M:`!@-)H]?^7%```L/D#`*ID"H!2E*(8D5S__Q>@
M``"PXP)`^>0#%*H"``"P`,A'^4)`&9$A`(!2$P"`T@``0/FM]?^7M`]`^;CG
M0ZF[*T#YI?__%V`#0+E_]?^7`!!"N0`@`!(?``=QP?G_5.`#$ZI-]?^7X0,5
MJO,#`*H```"P`$`:D0[[_Y<@"P"T]0)`^3'U_Y?A`P"JX`,5JC;]_Y?U`P"J
M0`H`M.`#%:H"]?^7^P,`JA\,`''M`0!4`'Q`DP$``+``$`#1(<`;D:`"`(N-
M]?^7``$`-7\3`''`(P!48!,`4:#"((L`\%\X'[P`<2`C`%2`_O^7P```-0$`
M@%+@`Q6JQ/7_EZ!W`+E`!P`U`0``L"%`&)$```"P`*`5D57[_Y<8(Q21&_7_
MEQ4``+"U@A^1Y@,`*@,``+#G`Q6JY0,8JN0#%*IC0!R1`@"`DB$`@%+@`Q.J
M%P``L-KT_Y?W@AR1$@``%!\@`]6Z]?^7``!`N1]$`'%!`@!4!O7_E_4#`/DY
M!P`1Y@,`*N<#&2KE`QBJY`,4JN,#%ZH"`("2(0"`4N`#$ZK']/^7`3B`4N`#
M$ZJP]?^7'P0`,8#]_U3@`Q2J;/7_E^$#$ZI`@Q.1*?O_E^`#$ZIS_O^7M`]`
M^;CG0ZF[<T6I/___%_4"0/FN__\7H^,&D4(`@%+U`P.J(0*`DJ,_`/D+]?^7
MH'=`N<(`@-+A`Q6J=_7_EZ#C1CF````UH.=&.1\,`7'@'`!4H'=`N0(`@%(!
M`(#2N<,#D;RC!)'\]/^7O_\1J2#C`)$D8(32(W&5TL*?F]+!CHK2H#<`^0`^
MG-*DZ*SRH_F]\D(7L_)!!J+R0'JX\J0/#ZFB!Q"IOVL!N:"+`/F@=T"Y`@"0
MTJ$_0/E7]?^7XP,`JO4#`"H?``!QK0@`5*6+4:EA?$"3H&M!N:0,`0N_``3K
M0I2"FD%T08NDAQ&I`!0`-`$(@%(U``!+H3]`^7\`%6NB-T#Y=="5&KM^0).C
M,P#Y0,`@B^(#&ZIC]/^7H&M!N:,S0/F@`@`+H&L!N1\``7'A^_]4H#]`^74`
M%4L;`!N+X`,9JB[V_Y>__@!QS0(`5+4"`5&@?@93H&,`N1=D&E/W`@&1=P,7
MBV`'0JF`!P*I9!=`J807`*EB#T&I@@\!J68?0ZF&'P.I>P,!D>`#&:H;]O^7
M_P(;ZX'^_U2@8T"YM1H`2Z`W0/D#"8#2HGY`D^$#&ZI\]/^7M6L!N:!W0+D"
M`)#2H3]`^1/U_Y?C`P"J]0,`*A\``'&L]_]4H'=`N;7T_Y>UWU&IX@^`$J$B
M`U,@!``1'^``<8++(3B,#0!4(^,`D0('@%)"``!+`0"`4D)\0)-@P""+@_3_
ME^'^6-/@_E#3H8,%.:'^6-.@AP4YX/Y(TZ"+!3F@_E#3H)<%.:#^2-.WCP4Y
MO",&D:&3!3F;HP"1M9\%.?4#'*J@FP4YX`,9JN;U_Y>YQP61IA=/J0```+"C
M"U"I%\`8D:&+0/G(_%#3Q_Q(TZ#\6-.I_%#3J,<%.:?+!3FH_$C39_Q8TZ#3
M!3E@_$C3Q'P84Z;/!3EJ_%#3J=<%.2;\6-.HVP4Y2?Q8TTC\4-.EWP4YI^,%
M.27\4--'_$C3H.L%.:3#!3D@_$C3JN<%.:/O!3FI\P4YJ/<%.:?[!3FB_P4Y
MI@,&.:4'!CF@"P8YH0\&.0,``!0?(`/5)!=`..`#%:KC`Q>J`@"`DB$`@%*U
M"@"1[O/_EW\#%>L!__]4!P``L.8#'*KG@!^1`P``L+_#!CD%(Q21Y`,4JF,`
M')$"`("2(0"`4N`#$ZK@\_^7'O__%[L_0/EV__\7]P9`^??<_[3@`Q>JU?/_
MEQ\,`/%IW/]4`!``T0$``+#@`@"+(>`;D6+T_Y<?``!QM1*7FMO^_Q<""(!2
M0@``2T)\0),!`(!2.^,`D6##((L8]/^7X`,9JHSU_Y>@@PB1'_PPJ3__!*D_
M_P6I/S<`^8[__Q>@ZT8Y'P0!<0'C_U2@[T8Y'PP!<:'B_U2@\T8Y'R`!<4'B
M_U2@]T8Y'Q0!<>'A_U2W=T"Y0@"`4B$'@)+@`Q<J"_3_E[4_0/DB!8#2X`,7
M*N$#%:IV]/^7!P``L.8#%:H#``"PYX`?D;___Q>XYP.INW,%J;0/`/D1]/^7
M_7NXJ:```+#]`P"1]QL`^;<``+#S4P&I\])'^?5;`JFUTP&1^B<`^0#<1_FU
M,P#Y`0!`^:$_`/D!`(#28`)`N?3S_Y?T`P"J8`)`N?'S_Y>!XD(Y`>0".0``
M`+#A`Q6J`"`5D87Y_Y>```"T`0!`.3_$`'$@%`!4G/S_E_;21_G``D"YX_/_
MEP$``+!C`8!2(@"`4B'@')'R\_^7(!8`M+@?`/FA``#0-2`"D:$W`/D!"$#Y
MV@)`N:`&0+DX%$#Y'P0`<>T9`%2Y(P#Y&8"`4KMS!:D4`(!2,P"`4AD$H'(+
M```4'R`#U6$(0/G@`QRJ]//_EZ$&0+D@!``U<P8`$90&`!$_`!-KK0,`5.`#
M&BK`\_^7`P"`4H)^0)/A`QBJ(/3_E_L#`*J`$P"T`P!`^:0&0/G:`D"Y8`Q`
MN9S8<_@``!D*'P`0<0#]_U3@`QHJL//_EV$#0/E#`(!2`@"`TISS_Y?A`P"J
MX`,<JM7S_Y?:`D"YH09`N2#\_S0@!`!1'P`4:R`,`%2XYT.INW-%J>`#&BJ?
M\_^78P"`4@$``)`B`(!2(0`=D:[S_Y?S`P"JH`$`M/321_F``D"YE?/_EV$*
M0/D"``"00B`=D2$`0/EP\_^78`I`^0``0/D`#$"Y0!"P-_321_F``D"YB?/_
MEP$``)!C`(!2(@"`4B%`'9&8\_^7\P,`JJ`!`+2A,T#Y````D`#`$Y$8^?^7
M]0,`JH`"0+GU#`"T>O/_EV$*0/GB`Q6J(0!`^5;S_Y?WTD?YH#=`^10@`I'@
M`D"Y<?/_E_,#`*K@`D"Y;O/_ER(`@%(!``"0(6`=D:+S_Y<"``"0X0,`JD+`
M'9'@`Q.J1?/_E^`"0+EC\_^7'^0".:$S0/D```"0`(`3D?CX_Y>`"@#Y\P,`
MJF`&`+0!.(!2X`,3JN#S_Y<!!``1/P0`<02(47JA"@!4H```D!K<1_FA/T#Y
M0`-`^2```,J`"0"U\U-!J?5;0JGW&T#Y^B=`^?U[R*C``U_6'R`#U0`$0#D`
M[/\T7O__%Q\@`]4_!`!Q[?/_5*`W0/DS`(!2]=)'^10@`I$#```4'R`#U;H"
M0+G@`QHJ.//_E^$#&*KN\O^7@`9`N7,&`!$?`!-K#/__5.#21_FXYT.INW-%
MJ1H`0+F-__\7H```L-H"0+F@-P#YB?__%X`&0/F]_/^7@`H`^?,#`*I`^?^U
M````D+CG`ZF[<P6I`.`=D5OS_Y>A-T#YX-)'^2$@`I$A!$"Y&@!`N2`$`%$?
M`!1KH>[_5-3__Q<?(`/5%//_EZ`W0/EB"D#Y`"`"D0$$0/E``$#Y(0!`^3'Z
M_Y>7__\7'R`#U8`"0+D)\_^780I`^2$`0/E:\_^7>O__%[@?0/EC__\7N.<#
MJ;MS!:D,\_^7H3=`^>,#`"J[<P6IX@,3JCP@`I&XYP.I`0``D""`'I&!!T#Y
M(0!`^3'S_Y?]>[ZI_0,`D?-3`:GT`P"J4OO_EP$`0#GS`P"JP0``-``$`)$_
MO`!Q<Q*`F@$`0#F!__\U#_S_EY\"`/$$&$!Z@0``5/-30:G]>\*HP`-?UH`"
M0#F`__\T`0``D((`@-(AX!B1X`,3JK[R_Y?`_O\UX`,4JO-30:G]>\*H;?G_
M%Z,``)!CX$?Y@P``M&,`0/F,\O\7'R`#U0,`@-*)\O\7_7N\J?T#`)'U6P*I
MM0``D/-3`:FT``"0M>(KD90"+)&4`A7+]V,#J?8#`JKX`P`J]P,!JCWR_Y>4
M_D.35`$`M!,`@-*C>G/XX@,6JN$#%ZK@`Q@J<P8`D6``/]:?`A/K(?__5/-3
M0:GU6T*I]V-#J?U[Q*C``U_6P`-?UOU[OZG]`P"1_7O!J,`#7]8``````0`"
M``````!P97)L>'-I+F,`````````7U]%3E9?4$%27T-,14%.7U\@("`@("`@
M("`@("`@("```````````"5S+R5S````+W!R;V,O<V5L9B]E>&4``$1Y;F%,
M;V%D97(Z.F)O;W1?1'EN84QO861E<@``````26YT97)N86QS.CI005(Z.D)/
M3U0`````97AE```````O<')O8R\E:2\E<P``````+@````````!005)?5$5-
M4```````````4$%27U!23T=.04U%`````#H`````````+P`````````E<R5S
M)7,``%!%4DPU3$E"``````````!015),3$E"`%!%4DPU3U!4``````````!0
M15),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1```````4$%27T-,
M14%.`````````%!!4E]$14)51P````````!005)?0T%#2$4`````````4$%2
M7T=,3T)!3%]$14)51P``````````4$%27T=,3T)!3%]435!$25(`````````
M4$%27U1-4$1)4@```````%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,
M14%.``````````!005)?0TQ%04X]````````,0````````!,1%],24)205)9
M7U!!5$@`4UE35$5-```E,#)X`````'!A<BT`````)7,E<R5S)7,`````````
M`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H```````!0051(`````"5S.B!P<FEV871E('-U8F1I
M<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E
M=')Y('EO=7(@;W!E<F%T:6]N*0H```````!P87)L`````"YP87(`````)7,E
M<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S
M``````````!!4D=6`````!@`````````<&5R;``````P`````````%!!4CHZ
M4&%C:V5R.CI615)324].`````#$N,#0P````56YA8FQE('1O(&-R96%T92!C
M86-H92!D:7)E8W1O<GD``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E
M(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````
M`````"5S````````+64````````M+0```````%5315(`````55-%4DY!344`
M`````````%1-4$1)4@``5$5-4$1)4@!414U0`````%1-4```````+W1M<```
M``!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*
M:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@
M7U]P87)?<&P["FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I
M.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ
M5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3
M<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A
M<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP
M(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD
M:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII
M9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M
M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$
M25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)
M6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B
M:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D
M<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A
M:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T
M;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M
M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^
M)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W
M;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*
M+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI0
M05(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*
M979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%2
M7T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]
M?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@
M/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D
M96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O
M)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H
M)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]?
M?2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0[
M"F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA
M;64["FUY("1O9F9S970@/2`U,3(["FUY("1I9'@@/2`M,3L*=VAI;&4@*#$I
M"GL*)&]F9G-E="`]("1S:7IE(&EF("1O9F9S970@/B`D<VEZ93L*<V5E:R!?
M1D@L("TD;V9F<V5T+"`R(&]R(&1I92!Q<5MS965K(&9A:6QE9"!O;B`B)'!R
M;V=N86UE(CH@)"%=.PIM>2`D;G)E860@/2!R96%D(%]&2"P@)&)U9BP@)&]F
M9G-E=#L*9&EE('%Q6W)E860@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T@
M=6YL97-S("1N<F5A9"`]/2`D;V9F<V5T.PHD:61X(#T@<FEN9&5X*"1B=68L
M(")<;E!!4BYP;5QN(BD["FQA<W0@:68@)&ED>"`^/2`P('Q\("1O9F9S970@
M/3T@)'-I>F4@?'P@)&]F9G-E="`^(#$R."`J(#$P,C0["B1O9F9S970@*CT@
M,CL*?0IL87-T('5N;&5S<R`D:61X(#X](#`["B1O9F9S970@+3T@)&ED>"`M
M(#0["G-E96L@7T9(+"`M)&]F9G-E="P@,CL*<F5A9"!?1D@L("1B=68L(#0[
M"G-E96L@7T9(+"`M)&]F9G-E="`M('5N<&%C:R@B3B(L("1B=68I+"`R.PIR
M96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0[
M"FUY("5R97%U:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR
M96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L
M("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN
M9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M
M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D
M8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN
M*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@
M+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]T96UP
M9FEL92@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U
M;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D
M9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%2
M7U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1B87-E;F%M
M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN
M(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z
M.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U
M9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@
M7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF
M+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M
M;V1U;&4["FUY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M
M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H:V5Y<R`E<F5Q=6ER
M95]L:7-T*2!["FYE>'0@=6YL97-S("]<421M;V1U;&5<120O.PHD:V5Y(#T@
M)%\[(&QA<W0["GT*9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F
M:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO
M861E<B\D9FEL96YA;64O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@
M86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&
M:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I
M;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T
M=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D
M9FEL96YA;64M/GMC<F-]+G!M(BP@)&9I;&5N86UE+3Y[8G5F?2D["F]P96X@
M;7D@)&9H+"`G/"<L("1F:6QE;F%M92!O<B!D:64@(F-A;B=T(')E860@)&9I
M;&5N86UE.B`D(2(["F)I;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@
M(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN
M(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(
M96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ
M2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER
M92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@
M)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@
M;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@
M+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@
M)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<
M+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]
M"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S
M(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@
M)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!
M4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U
M<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)5
M1WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P
M=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L
M:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS
M("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D
M05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%2
M7T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@
M<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@
M>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L
M87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]
M"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H
M)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H
M)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2![
M"B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N
M9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q
M.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R
M(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I9B`H
M)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I
M.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[
M)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF
M>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$
M:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@
M0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@
M24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1P87(@/2!S
M:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*07)C
M:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H,3(X*C$P,C0I.PIO<&5N(&UY("1F
M:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2([
M"F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]
M($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L
M92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I
M92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII
M9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY
M;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>
M7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I]
M.PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2
M+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*
M9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@
M(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z
M.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W
M+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D
M871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P
M.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%
M4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q
M=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13
M=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*9F]R96%C:"!M>2`D
M:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O
M<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*
M;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM
M>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R
M(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE
M;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D
M;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!0
M05(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN
M:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![
M("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D
M7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#
M;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*;7D@)69I;&5S
M.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J
M96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N
M9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES
M("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER
M("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%
M7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I
M.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:
M(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD
M,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L
M<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O
M)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA
M;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F
M:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO
M:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M
M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H
M)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO
M<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE
M.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S
M92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C
M;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA
M;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#
M;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*
M?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&
M24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y
M*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI:
M:7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R
M:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H
M)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I
M9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@
M-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O
M=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI3
M2$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$
M:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E
M<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H
M85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\
M(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO
M;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D
M8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O
M=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO
M<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I
M9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@
M;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*
M)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L
M("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*")<
M;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X
M:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?
M<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C
M:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*;7D@
M)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL
M("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D1G)O;49I;&5(86YD
M;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O
M<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B10
M05(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.
M5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6
M>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@
M(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE
M;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$
M:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE
M.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH
M/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N
M9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA
M;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H
M)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?
M;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@
M>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L
M<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S
M*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B
M*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*
M8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]
M"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE
M(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=
M(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M
M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6
M*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER
M92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I
M(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI
M.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T
M:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R
M"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E
M($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0[
M"G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P
M.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E
M($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&
M8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,[
M"G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/
M.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z
M.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E(%!!4CL*<F5Q
M=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A
M=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER
M92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I
M<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N
M>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D
M0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R
M;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?
M<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD
M("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*
M<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q
M=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H
M($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P
M871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*
M;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D
M969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@
M*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD
M969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92![
M"B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@
M)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I
M<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D
M=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!
M4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=
M*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PIS965K("1F:"P@
M+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*:68@*"1B=68@97$@
M(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y<W)E860@)&9H+"`D
M8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O;F9I
M9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS92!["FUY("1C='@@/2!E
M=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q
M*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI3
M2$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG
M97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I
M9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E
M<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA
M9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF
M("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PIB:6YM
M;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]
M"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X
M(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["GT*8VQO<V4H)&9H*3L*
M?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#
M;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T
M;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M
M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]
M?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D;F%M92P@)&-O;G1E
M;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D
M;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]
M("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@)SXG+"`D=&5M<&YA;64@
M;W(@9&EE(")C86XG="!W<FET92`D=&5M<&YA;64Z("0A(CL*8FEN;6]D92`D
M9F@["G!R:6YT("1F:"`D8V]N=&5N=',["F-L;W-E("1F:#L*8VAM;V0@)&UO
M9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N
M86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R
M;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE
M9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]
M?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D
M,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%
M3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O
M9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q
M*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA
M;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L
M("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US
M("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)$-O
M;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI
M="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT
M(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!
M4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H
M)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N
M9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA
M;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII
M9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD
M<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@
M)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I
M"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H
M*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<
M+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO
M.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?
M:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@
M*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@
M,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@
M4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*9&5L971E("1%3E9[)U!!4E\G
M+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2![
M"B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@
M97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A
M;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D
M14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L
M<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A
M;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I
M*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,
M14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*
M:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP
M<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I
M9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF
M:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP
M('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP
M86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2
M.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A
M<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@
M<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE
M.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+
M7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/
M4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2
M(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@
M)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````4"0````````()`````````$`
M`````````0`````````!`````````,L!`````````0````````#6`0``````
M``$`````````X`$````````!`````````"\"`````````0````````"*`P``
M``````$`````````L@,````````,`````````,@<````````#0`````````<
M5````````!D`````````^)H!```````;``````````@`````````&@``````
M````FP$``````!P`````````"`````````#U_O]O`````&`"````````!0``
M``````"@#0````````8`````````4`,````````*`````````!<%````````
M"P`````````8`````````!4````````````````````#`````````%B=`0``
M`````@``````````!@```````!0`````````!P`````````7`````````,@6
M````````!P````````#X$P````````@`````````T`(````````)````````
M`!@`````````'@`````````(`````````/O__V\``````0``"`````#^__]O
M`````)@3````````____;P`````#`````````/#__V\`````N!(```````#Y
M__]O`````!$`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````#@'````````.`<````````
MX!P```````#@'````````.`<````````X!P```````#@'````````.`<````
M````X!P```````#@'````````.`<````````X!P```````#@'````````.`<
M````````X!P```````#@'````````.`<````````X!P```````#@'```````
M`.`<````````X!P```````#@'````````.`<````````X!P```````#@'```
M`````.`<````````X!P```````#@'````````.`<````````X!P```````#@
M'````````.`<````````X!P```````#@'````````.`<````````X!P`````
M``#@'````````.`<````````X!P```````#@'````````.`<````````X!P`
M``````#@'````````.`<````````X!P```````#@'````````.`<````````
MX!P```````#@'````````.`<````````X!P```````#@'````````.`<````
M````X!P```````#@'````````.`<````````X!P```````#@'````````.`<
M````````X!P```````#@'````````.`<````````X!P```````#@'```````
M``B;`0``````&%0`````````````````````````````````````````````
M````````````````````````````````````````````````"*`!````````
M`````````*!3````````````````````(0``````````````````````````
M````````````````````````"*`!``````#_____`````#A8````````V%0`
M`````````````````,A5````````&%@````````@6````````"A8````````
M,%@```````````````````!8````````"%@``````````````````$!8````
M````1T-#.B`H1&5B:6%N(#<N,BXP+3$Q*2`W+C(N,`!'0T,Z("A$96)I86X@
M-BXT+C`M-"D@-BXT+C`@,C`Q-S`X,C```"YS:'-T<G1A8@`N:6YT97)P`"YN
M;W1E+D%"22UT86<`+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N9'EN
M<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA
M+F1Y;@`N<F5L82YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?
M9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N
M9&%T80`N8G-S`"YC;VUM96YT````````````````````````````````````
M``````````````````````````````````````````````````````L````!
M`````@```````````@`````````"````````&P````````````````````$`
M```````````````````3````!P````(`````````'`(````````<`@``````
M`"`````````````````````$````````````````````(0````<````"````
M`````#P"````````/`(````````D````````````````````!```````````
M`````````#0```#V__]O`@````````!@`@```````&`"````````[```````
M```%``````````@````````````````````^````"P````(`````````4`,`
M``````!0`P```````%`*````````!@````,````(`````````!@`````````
M1@````,````"`````````*`-````````H`T````````7!0``````````````
M`````0```````````````````$X```#___]O`@````````"X$@```````+@2
M````````W``````````%``````````(``````````@````````!;````_O__
M;P(`````````F!,```````"8$P```````&``````````!@````,````(````
M````````````````:@````0````"`````````/@3````````^!,```````#0
M`@````````4`````````"``````````8`````````'0````$````0@``````
M``#(%@```````,@6``````````8````````%````%`````@`````````&```
M``````!^`````0````8`````````R!P```````#('````````!0`````````
M```````````$````````````````````>0````$````&`````````.`<````
M````X!P````````@!```````````````````$``````````0`````````(0`
M```!````!@``````````(0`````````A````````'#,`````````````````
M``@```````````````````"*`````0````8`````````'%0````````<5```
M`````!`````````````````````$````````````````````D`````$````"
M`````````#!4````````,%0```````!(0```````````````````"```````
M`````````````)@````!`````@````````!XE````````'B4````````!```
M``````````````````0```````````````````"B````#@````,`````````
M^)H!``````#XF@````````@````````````````````(``````````@`````
M````K@````\````#``````````";`0```````)L````````(````````````
M````````"``````````(`````````+H````&`````P`````````(FP$`````
M``B;````````4`(````````&``````````@`````````$`````````##````
M`0````,`````````6)T!``````!8G0```````*@"```````````````````(
M``````````@`````````R`````$````#``````````"@`0```````*``````
M``"`````````````````````"````````````````````,X````(`````P``
M``````"`H`$``````("@````````*!````````````````````@`````````
M``````````#3`````0```#````````````````````"`H````````$(`````
M```````````````!``````````$``````````0````,`````````````````
M````````PJ````````#<`````````````````````0``````````````````
!````
